pub struct WindowOpt {
pub dim: WindowDim,
pub num_samples: Option<u32>,
}luminance-windowing is not maintained anymore; please directly use the platform crates from now on
Different window options.
Feel free to look at the different methods available to tweak the options. You may want to start
with default(), though.
Fields
dim: WindowDimluminance-windowing is not maintained anymore; please directly use the platform crates from now on
Dimension of the window.
num_samples: Option<u32>luminance-windowing is not maintained anymore; please directly use the platform crates from now on
Number of samples for multisampling.
None means no multisampling.
Implementations
Sourceimpl WindowOpt
impl WindowOpt
Sourcepub fn set_dim(self, dim: WindowDim) -> Self
👎Deprecated: luminance-windowing is not maintained anymore; please directly use the platform crates from now on
pub fn set_dim(self, dim: WindowDim) -> Self
luminance-windowing is not maintained anymore; please directly use the platform crates from now on
Set the dimension of the window.
Sourcepub fn dim(&self) -> &WindowDim
👎Deprecated: luminance-windowing is not maintained anymore; please directly use the platform crates from now on
pub fn dim(&self) -> &WindowDim
luminance-windowing is not maintained anymore; please directly use the platform crates from now on
Get the dimension of the window.
Sourcepub fn set_num_samples<S>(self, num_samples: S) -> Self
👎Deprecated: luminance-windowing is not maintained anymore; please directly use the platform crates from now on
pub fn set_num_samples<S>(self, num_samples: S) -> Self
luminance-windowing is not maintained anymore; please directly use the platform crates from now on
Set the number of samples to use for multisampling.
Pass None to disable multisampling.
Sourcepub fn num_samples(&self) -> &Option<u32>
👎Deprecated: luminance-windowing is not maintained anymore; please directly use the platform crates from now on
pub fn num_samples(&self) -> &Option<u32>
luminance-windowing is not maintained anymore; please directly use the platform crates from now on
Get the number of samples to use in multisampling, if any.